﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace Netzlast
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            Netzelement[] elemente =
            {
                new Glühlampe(60),
                new Glühlampe(60),
                new Glühlampe(60),
                new Glühlampe(60),
                new Glühlampe(60),
                new Glühlampe(60),
                new Glühlampe(40),
                new Glühlampe(40),
                new Waschmaschine(),
                new Photovoltaikanlage(1.0),
                new MiniWKA(2.0, 1.0)
            };
            double[] last = new double[24 * 60];
            for (int minute = 0; minute < 24 * 60; minute++)
            {
                DateTime wann = DateTime.Today.AddMinutes(minute);
                for (int i = 0; i < elemente.Length; i++)
			    {
                    last[minute] += elemente[i].BestimmeLeistung(wann);			 
			    }
            }

            double maxLast = last.Max();
            double minLast = Math.Min(0.0, last.Min()); // mindestens immer bis zur Null hinab

            double x1 = Canvas.GetLeft(Graph);
            double y1 = Canvas.GetTop(Graph);

            Line nullLinie = new Line();
            nullLinie.Stroke = Brushes.Green;
            nullLinie.StrokeThickness = 1.0;
            nullLinie.X1 = x1;
            nullLinie.X2 = x1 + Graph.Width;
            nullLinie.Y1 = nullLinie.Y2 = y1 + maxLast / (maxLast - minLast) * Graph.Height;
            Zeichenfläche.Children.Add(nullLinie);

            Polyline linie = new Polyline();
            linie.Stroke = Brushes.Blue;
            linie.StrokeThickness = 2.0;
            linie.StrokeMiterLimit = 0.0;
            for (int minute = 0; minute < 24 * 60; minute++)
            {
                linie.Points.Add(new Point(Graph.Width * minute / (24 * 60), Graph.Height * (1.0 - (last[minute] - minLast)/(maxLast - minLast))));
            }
            Graph.Children.Add(linie);



            // ab hier nur noch grafischer Schnickschnack

            for (int stunde = 0; stunde <= 24; stunde++)
            {
                Line strich = new Line();
                strich.Stroke = Brushes.Black;
                strich.StrokeThickness = 1.0;
                double x = Canvas.GetLeft(Graph) + stunde / 24.0 * Graph.Width;
                strich.X1 = strich.X2 = x;
                double y = Canvas.GetTop(Graph) + Graph.Height;
                strich.Y1 = y;
                strich.Y2 = y + 10.0;
                Zeichenfläche.Children.Add(strich);

                TextBlock beschriftung = new TextBlock();
                beschriftung.TextAlignment = TextAlignment.Center;
                beschriftung.Width = 20.0;
                beschriftung.Text = stunde.ToString();
                Canvas.SetLeft(beschriftung, x - 10.0);
                Canvas.SetTop(beschriftung, y + 13.0);
                Zeichenfläche.Children.Add(beschriftung);
            }

            Line strichOben = new Line();
            strichOben.Stroke = Brushes.Black;
            strichOben.StrokeThickness = 1.0;
            strichOben.X1 = x1;
            strichOben.X2 = x1 - 10.0;
            strichOben.Y1 = strichOben.Y2 = y1;
            Zeichenfläche.Children.Add(strichOben);

            TextBlock beschriftungOben = new TextBlock();
            beschriftungOben.TextAlignment = TextAlignment.Right;
            beschriftungOben.Width = 100.0;
            beschriftungOben.Text = maxLast.ToString("e3");
            Canvas.SetLeft(beschriftungOben, x1 - 13.0 - beschriftungOben.Width);
            Canvas.SetTop(beschriftungOben, y1 - 0.7 * beschriftungOben.FontSize);
            Zeichenfläche.Children.Add(beschriftungOben);

            Line strichUnten = new Line();
            strichUnten.Stroke = Brushes.Black;
            strichUnten.StrokeThickness = 1.0;
            strichUnten.X1 = x1;
            strichUnten.X2 = x1 - 10.0;
            double y2 = Canvas.GetTop(Graph) + Graph.Height;
            strichUnten.Y1 = strichUnten.Y2 = y2;
            Zeichenfläche.Children.Add(strichUnten);

            TextBlock beschriftungUnten = new TextBlock();
            beschriftungUnten.TextAlignment = TextAlignment.Right;
            beschriftungUnten.Width = 100.0;
            beschriftungUnten.Text = minLast.ToString("e3");
            Canvas.SetLeft(beschriftungUnten, x1 - 13.0 - beschriftungUnten.Width);
            Canvas.SetTop(beschriftungUnten, y2 - 0.7 * beschriftungUnten.FontSize);
            Zeichenfläche.Children.Add(beschriftungUnten);
        }
    }
}
